types

package
v1.34.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 20, 2026 License: Apache-2.0 Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ChildAttributes

func ChildAttributes(value attr.Value) (bool, map[string]attr.Value)

func ChildItems

func ChildItems(value attr.Value) (bool, []attr.Value)

func FloatValue

func FloatValue(value attr.Value) (bool, *big.Float)

func IntValue

func IntValue(value attr.Value) (bool, *big.Int)

func NewFloat64Value added in v1.31.1

func NewFloat64Value(value float64) basetypes.Float64Value

Alternative to basetypes.NewFloat64Value that takes a float64 and converts it to a big.Float with precision and rounding to match that of HCL config parsing instead of 53-bit precision.

func NewFloat64ValueFromBigFloat added in v1.31.1

func NewFloat64ValueFromBigFloat(value *big.Float) (basetypes.Float64Value, error)

Alternative to basetypes.NewFloat64Value that takes a *big.Float with arbitrary precision directly instead of taking a float64 at 53-bit precision.

func NewFloat64ValueFromString added in v1.31.1

func NewFloat64ValueFromString(value string) (basetypes.Float64Value, error)

Creates a basetypes.Float64Value from a string where the underlying *big.Float has precision matching that of HCL config parsing.

func NewFloat64ValueFromStringUnsafe added in v1.31.1

func NewFloat64ValueFromStringUnsafe(value string) basetypes.Float64Value

Creates a basetypes.Float64Value from a string where the underlying *big.Float has precision matching that of HCL config parsing. Panics on error.

func NewNumberValueFromString added in v1.31.1

func NewNumberValueFromString(value string) (basetypes.NumberValue, error)

Creates a basetypes.NumberValue from a string where the underlying *big.Float has precision matching that of HCL config parsing.

func NewNumberValueFromStringUnsafe added in v1.31.1

func NewNumberValueFromStringUnsafe(value string) basetypes.NumberValue

Creates a basetypes.NumberValue from a string where the underlying *big.Float has precision matching that of HCL config parsing. Panics on error.

Types

This section is empty.

Jump to